#ifndef COMMENT_H
#define COMMENT_H

#include <QObject>
#include <QDateTime>


class Comment : public QObject
{
    Q_OBJECT
public:
    explicit Comment(QObject *parent = 0);

    QString getAuthorName() {return _authorName;}
    void setAuthorName(QString name) {_authorName = name;}
    qint64 getAuthorId() {return _authorId;}
    void setAuthorId(qint64 authorId) {_authorId = authorId;}
    QString getText() {return _text;}
    void setText(QString text) {_text = text;}
    QDateTime getTimestamp() {return _timestamp;}
    void setTimestamp(QDateTime timestamp) {_timestamp = timestamp;}

signals:

public slots:

private:
    QString _authorName;
    qint64 _authorId;
    QString _text;
    QDateTime _timestamp;

};

#endif // COMMENT_H
